Crate clawedcode_tools

Crate clawedcode_tools 

Structs

ApplyPatch
Applies structured edits to files under cwd.
ReadFile
Reads a file under cwd with a size limit.
Shell
Runs a shell command in cwd.
ToolResult
Result of executing a tool.
ToolSpec

Traits

Tool
A tool that can be invoked by the runtime.

Functions

builtin_tool_instances
Returns all built-in tool instances.
builtin_tools
Returns the ToolSpec list for API compatibility (kept for existing code).